<?php

namespace App\Http\Controllers;

use App\Models\cinerarios;
use App\Models\nichos;
use App\Models\pabellon;
use Illuminate\Http\Request;

class PabellonController extends Controller
{
  /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pabellon = pabellon::orderBy('id', 'asc')->get();
        $nicho = nichos::orderBy('id', 'asc')->get();
        $cinerarios = cinerarios::orderBy('id', 'asc')->get();
        return view('pabellones.index', compact('pabellon','nicho','cinerarios'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
{
     // Validación de datos
     $request->validate([
        'nombre_pabellon' => 'required|string|max:255',
        'foto' => 'image|mimes:jpeg,png,jpg,gif|max:2048',
        'lado_pabellon' => 'required|string|max:255',
        'numero_cinerarios' => 'required|integer|min:1', // Add validation for numero_cinerarios
    ]);

    // Crear el nuevo pabellón
    $pabellon = new Pabellon();
    $pabellon->nombre_pabellon = $request->input('nombre_pabellon');
    $pabellon->lado_pabellon = $request->input('lado_pabellon');

    if ($request->hasFile('foto')) {
        $file = $request->file('foto');
        $destinationPath = 'img/foto';
        $filename = time() . '-' . $file->getClientOriginalName();
        if ($file->move($destinationPath, $filename)) {
            // Save the image path relative to the pavilion
            $pabellon->imagen_pabellon = $destinationPath . '/' . $filename; // Follow snake_case convention
        } else {
            return response()->json(['success' => false, 'message' => 'Error al subir la foto']);
        }
    }

    // Definir las filas y columnas
    $filas = 7;
    $columnas = 42;

    $pabellon->filas_pabellon = $filas;
    $pabellon->columnas_pabellon = $columnas;
    $pabellon->numero_cinerarios = $request->input('numero_cinerarios');
    $pabellon->save();

    // Generar los nichos para este pabellón
    $nichos = [];
    $letras = range('G', 'A'); // Array con las letras de A a F

    foreach ($letras as $letra) {
        for ($j = 1; $j <= $columnas; $j++) {
            $nichos[] = [
                'id_pabellon' => $pabellon->id,
                'fila' => $letra,
                'columna' => $j,
                'estado_nicho' => 'Libre', // Asignar estado inicial
                'created_at' => now(),
                'updated_at' => now(),
            ];
        }
    }

    // Insertar todos los nichos en una sola consulta
    Nichos::insert($nichos);

    // Generar los cinerarios para este pabellón
    $cinerarios = [];
    for ($i = 1; $i <= $pabellon->numero_cinerarios; $i++) {
        $cinerarios[] = [
            'id_pabellon' => $pabellon->id,
            'numero' => $i,
            'estado_cinerario' => 'Libre', // Asignar estado inicial
            'created_at' => now(),
            'updated_at' => now(),
        ];
    }

    // Insertar todos los cinerarios en una sola consulta
    Cinerarios::insert($cinerarios);

    return redirect()->back()->with('info', 'Guardado correctamente');
}

    public function show(string $id)
    {


    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {

    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request,$id)
    {
        $pabellon=pabellon::find($id);
        $pabellon->nombre_pabellon = $request->input('nombre_pabellon');
        $pabellon->filas = $request->input('filas_pabellon');
        $pabellon->columnas = $request->input('columnas_pabellon');
        $pabellon->lado_pabellon = $request->input('lado_pabellon');
        $pabellon->update();
        return redirect()->back()->with('info', 'guardado Correctamente');

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }

}
