<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\Http;
use App\Models\detalle_recibo;
use App\Models\difunto;
use App\Models\familiar;
use App\Models\nichos;
use App\Models\recibo;
use Illuminate\Http\Request;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Support\Facades\DB;
use Svg\Tag\Rect;
use Illuminate\Support\Facades\Log;
use Illuminate\Validation\Rule;


class ReciboController extends Controller
{
       
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $recibos = recibo::orderBy('id', 'desc')->paginate(10); // Cambia 10 al número de elementos por página que desees
        $familiar = familiar::all();
        $difunto = difunto::all();
        return view('recibo.index', compact('recibos','familiar','difunto'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create($id_nicho)
    {
        $nicho = nichos::findOrFail($id_nicho); // Assuming Nicho is your model name
        $familiar = familiar::all();
        $difunto = difunto::all();
        $recibos = recibo::all();
        return view('recibo.create', compact('nicho','familiar','difunto','recibos'));
    }
    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validatedData = $request->validate([
            'nombre_difunto' => 'required|string|max:255',
            'apellido_paterno_difunto' => 'required|string|max:255',
            'apellido_materno_difunto' => 'required|string|max:255',
            'dni_difunto' => 'required|string|max:20',
            'causa_muerte' => 'nullable|string|max:255',
            'acta_defuncion' => 'nullable|string|max:255',
            'certificado_defuncion' => 'nullable|string|max:255',
            'fecha_muerte' => 'nullable|date',
            'id_nicho' => 'required|integer|exists:nichos,id',
            'nombre_familiar' => 'required|string|max:255',
            'apellido_paterno_familiar' => 'required|string|max:255',
            'apellido_materno_familiar' => 'required|string|max:255',
             'dni_familiar' => 'required|string|max:20',
            'parentesco' => 'required|string|max:255',
            'estado_nicho' => 'required|string|max:255',
            'precio_nicho' => 'required|numeric',
        ]);
    
        DB::beginTransaction();
    
        try {
            // Crear un nuevo registro para difunto
            $difunto = new difunto();
            $difunto->nombre = $request->nombre_difunto;
            $difunto->apellido_paterno = $request->apellido_paterno_difunto;
            $difunto->apellido_materno = $request->apellido_materno_difunto;
            $difunto->dni = $request->dni_difunto;
            $difunto->causa_de_muerte = $request->causa_muerte;
            $difunto->acta_de_defuncion = $request->acta_defuncion;
            $difunto->certificado_de_defuncion = $request->certificado_defuncion;
            $difunto->fecha_muerte = $request->fecha_muerte;
            $difunto->id_nicho = $request->id_nicho;
            $difunto->save();
    
            // Crear un nuevo registro para familiar
            $familiar = new familiar();
            $familiar->nombre = $request->nombre_familiar;
            $familiar->apellido_paterno = $request->apellido_paterno_familiar;
            $familiar->apellido_materno = $request->apellido_materno_familiar;
            $familiar->dni = $request->dni_familiar;
            $familiar->parentesco = $request->parentesco;
            $familiar->id_difunto = $difunto->id;
            $familiar->save();
    
            // Crear un nuevo registro para el recibo
            $recibo = new recibo();
            $recibo->id_familiar = $familiar->id;
            $recibo->estado = 'Activo';
            $recibo->fecha = now();
            $recibo->save();
    
            // Crear un nuevo registro para detalle_recibo
            $detalle_recibo = new detalle_recibo();
            $detalle_recibo->id_recibo = $recibo->id;
            $detalle_recibo->id_nicho = $request->id_nicho;
            $detalle_recibo->id_difunto = $difunto->id;
            $detalle_recibo->save();
    
            // Actualizar el estado y el precio del nicho
            $nicho = nichos::find($request->id_nicho);
            $nicho->estado_nicho = $request->estado_nicho;
            $nicho->precio_nicho = $request->precio_nicho;
            $nicho->save();
    
            // Confirmar la transacción
            DB::commit();
    
            return response()->json(['success' => true, 'message' => 'Venta realizada con éxito', 'recibo_id' => $recibo->id]);
        } catch (\Exception $e) {
            // Deshacer la transacción en caso de error
            DB::rollBack();
    
            return response()->json(['success' => false, 'message' => 'Error al realizar la venta', 'error' => $e->getMessage()]);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(recibo $recibos)
    {
      
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }
   
        public function export(string $id)
{
        $recibos = recibo::with('familiar', 'detalle_recibo')->find($id);
        $pdf = pdf::loadView('recibo.export', ['recibos' => $recibos]);
        return $pdf->stream('boleta.pdf');
}
public function buscarDni($dni)
{
    $token = env('API_TOKEN');
    $url = "https://dniruc.apisperu.com/api/v1/dni/{$dni}?token={$token}";

    try {
        $response = Http::get($url);

        if ($response->successful()) {
            return response()->json(['success' => true, 'data' => $response->json()]);
        } else {
            return response()->json(['success' => false, 'message' => 'Error al consultar el DNI']);
        }
    } catch (\Exception $e) {
        return response()->json(['success' => false, 'message' => 'Error al consultar el DNI', 'error' => $e->getMessage()]);
    }
}
public function search(Request $request)
{
    $searchTerm = $request->input('query');

    // Filtrar los resultados con el término de búsqueda
    $recibos = Recibo::whereHas('familiar', function($query) use ($searchTerm) {
        $query->where('nombre', 'LIKE', '%' . $searchTerm . '%')
              ->orWhere('apellido_paterno', 'LIKE', '%' . $searchTerm . '%')
              ->orWhere('apellido_materno', 'LIKE', '%' . $searchTerm . '%');
    })->paginate(10); // Pagina los resultados si es necesario

    return view('recibo.table', compact('recibos'));
}

}
