<?php

namespace App\Http\Controllers;

use App\Models\detalle_lapida;
use App\Models\lapida;
use App\Models\sepultado;
use App\Models\solicitante;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Barryvdh\DomPDF\Facade\Pdf;

class lapidaController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $lapida = lapida::orderBy('id', 'desc')->paginate(8);
        return view('lapida.index', compact('lapida'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $lapida = lapida::all();
        return view('lapida.create', compact('lapida'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
    // Validate request data
    $validatedData = $request->validate([
        // Add validation rules here
    ]);

    // Obtener datos del formulario
    $solicitantes = $request->input('solicitante');
    $dni = $request->input('dni');
    $fallecido = $request->input('fallecido');
    $costo = $request->input('costo');

    // Iniciar la transacción
    DB::beginTransaction();

    try {
       // Insertar los datos del sepultado
       $sepultado = new sepultado();
       $sepultado->nombres = $fallecido;
       $sepultado->save();

        // Insertar los datos del sepultado
        $solicitante = new solicitante();
        $solicitante->nombre = $solicitantes;
        $solicitante->dni = $dni;
        $solicitante->save();

        // Obtener el ID del apoderado recién creado
        $id_sepultado = $sepultado->id;
        $id_solicitante = $solicitante->id;

         // Crear el lapida
         $lapida = new lapida();
         $lapida->id_solicitante = $id_solicitante;
         $lapida->fecha = now();
         $lapida->save();
        // Obtener el ID del apoderado recién creado
         $id_lapida = $lapida->id;

           // Crear detalle lapida

           $detalle_lapida = new detalle_lapida();
           $detalle_lapida->id_sepultado = $id_sepultado;
           $detalle_lapida->id_lapida = $id_lapida;
           $detalle_lapida->costo = $costo;
           $detalle_lapida->save();


       // Confirmar la transacción
       DB::commit();
    
       return response()->json(['success' => true, 'message' => 'Pago realizado con éxito', 'lapida_id' => $lapida->id]);
   } catch (\Exception $e) {
       // Deshacer la transacción en caso de error
       DB::rollBack();

       return response()->json(['success' => false, 'message' => 'Error al realizar el Pago', 'error' => $e->getMessage()]);
   }

    }

    /**
     * Display the specified resource.
     */
    public function show(lapida $lapida)
    {
        $lapida->load('solicitante', 'detalle_lapida');
        return view('lapida.show', compact('lapida'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }

    public function export(string $id)
    {
        $lapida = lapida::with('solicitante', 'detalle_lapida')->find($id);
        $pdf = pdf::loadView('lapida.export', ['lapida' => $lapida]);
        return $pdf->stream('boleta_de_lapida.pdf');
    }
    public function search(Request $request)
    {
        $searchTerm = $request->input('query');
        
        // Filtrar los resultados con el término de búsqueda
        $lapida = Lapida::whereHas('solicitante', function($query) use ($searchTerm) {
            $query->where('nombre', 'LIKE', '%' . $searchTerm . '%');
        })->paginate(10); // Pagina los resultados si es necesario
        
        return view('lapida.table', compact('lapida'));
    }
    


}
