<?php

namespace App\Http\Controllers;

use App\Models\cinerarios;
use App\Models\detalle_recibo_cinerario;
use App\Models\difuntos_cremados;
use App\Models\familiar_difuntos_cremados;
use App\Models\nichos;
use App\Models\recibo_cinerario;
use Illuminate\Http\Request;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

class recibo_cinerariosController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $recibo_cinerarios = recibo_cinerario::with(['familiar_difuntos_cremados', 'detalle_recibo_cinerario'])->orderBy('id', 'desc')->paginate(10);
        return view('recibo_cinerario.index', compact('recibo_cinerarios'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create($id_cinerarios)
    {
        $cinerarios = cinerarios::findOrFail($id_cinerarios); // Assuming Nicho is your model name
        $familiar_difuntos_cremados = familiar_difuntos_cremados::all();
        $difuntos_cremados = difuntos_cremados::all();
        $recibo_cinerario = recibo_cinerario::all();
        return view('recibo_cinerario.create', compact('cinerarios','familiar_difuntos_cremados','difuntos_cremados','recibo_cinerario'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validatedData = $request->validate([
            'nombre_difunto' => 'required|string|max:255',
            'apellido_paterno_difunto' => 'required|string|max:255',
            'apellido_materno_difunto' => 'required|string|max:255',
            'dni_difunto' => 'required|string|max:20|unique:difuntos_cremados,dni',
            'causa_muerte' => 'required|string|max:255',
            'acta_defuncion' => 'nullable|string|max:255',
            'certificado_defuncion' => 'nullable|string|max:255',
            'fecha_muerte' => 'required|date',
            'id_cinerario' => 'required|integer|exists:cinerarios,id',
            'nombre_familiar' => 'required|string|max:255',
            'apellido_paterno_familiar' => 'required|string|max:255',
            'apellido_materno_familiar' => 'required|string|max:255',
            'dni_familiar' => 'required|string|max:20|unique:familiar_difuntos_cremados,dni',
            'parentesco' => 'required|string|max:255',
            'estado_cinerario' => 'required|string|max:255',
            'precio_cinerario' => 'required|numeric',
        ]);
    
        DB::beginTransaction();
    
        try {
            // Crear un nuevo registro para difunto
            $difuntos_cremados = new difuntos_cremados();
            $difuntos_cremados->nombre = $request->nombre_difunto;
            $difuntos_cremados->apellido_paterno = $request->apellido_paterno_difunto;
            $difuntos_cremados->apellido_materno = $request->apellido_materno_difunto;
            $difuntos_cremados->dni = $request->dni_difunto;
            $difuntos_cremados->causa_de_muerte = $request->causa_muerte;
            $difuntos_cremados->acta_de_defuncion = $request->acta_defuncion;
            $difuntos_cremados->certificado_de_defuncion = $request->certificado_defuncion;
            $difuntos_cremados->fecha_muerte = $request->fecha_muerte;
            $difuntos_cremados->id_cinerario = $request->id_cinerario;
            $difuntos_cremados->save();
    
            // Crear un nuevo registro para familiar
            $familiar_difuntos_cremados = new familiar_difuntos_cremados();
            $familiar_difuntos_cremados->nombre = $request->nombre_familiar;
            $familiar_difuntos_cremados->apellido_paterno = $request->apellido_paterno_familiar;
            $familiar_difuntos_cremados->apellido_materno = $request->apellido_materno_familiar;
            $familiar_difuntos_cremados->dni = $request->dni_familiar;
            $familiar_difuntos_cremados->parentesco = $request->parentesco;
            $familiar_difuntos_cremados->id_difunto_cremado = $difuntos_cremados->id;
            $familiar_difuntos_cremados->save();
    
            // Crear un nuevo registro para el recibo
            $recibo_cinerario = new recibo_cinerario();
            $recibo_cinerario->id_familiar_difunto_cremado = $familiar_difuntos_cremados->id;
            $recibo_cinerario->estado = 'Activo';
            $recibo_cinerario->fecha = now();
            $recibo_cinerario->save();
    
            // Crear un nuevo registro para detalle_recibo
            $detalle_recibo_cinerario = new detalle_recibo_cinerario();
            $detalle_recibo_cinerario->id_recibo_cinerarios = $recibo_cinerario->id;
            $detalle_recibo_cinerario->id_cinerarios = $request->id_cinerario;
            $detalle_recibo_cinerario->id_difunto_cremado = $difuntos_cremados->id;
            $detalle_recibo_cinerario->save();
    
            // Actualizar el estado y el precio del cinerario
            $cinerarios = Cinerarios::find($request->id_cinerario);
            $cinerarios->estado_cinerario = $request->estado_cinerario;
            $cinerarios->precio_cinerario = $request->precio_cinerario;
            $cinerarios->save();
    
            // Confirmar la transacción
            DB::commit();
    
            return response()->json(['success' => true, 'message' => 'Venta realizada con éxito', 'recibo_cinerario_id' => $recibo_cinerario->id]);
        } catch (\Exception $e) {
            // Deshacer la transacción en caso de error
            DB::rollBack();
    
            return response()->json(['success' => false, 'message' => 'Error al realizar la venta', 'error' => $e->getMessage()]);
        }
    }
    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }
    public function buscarDni($dni)
{
    $token = env('API_TOKEN');
    $url = "https://dniruc.apisperu.com/api/v1/dni/{$dni}?token={$token}";

    try {
        $response = Http::get($url);

        if ($response->successful()) {
            return response()->json(['success' => true, 'data' => $response->json()]);
        } else {
            return response()->json(['success' => false, 'message' => 'Error al consultar el DNI']);
        }
    } catch (\Exception $e) {
        return response()->json(['success' => false, 'message' => 'Error al consultar el DNI', 'error' => $e->getMessage()]);
    }
}
public function export(string $id)
{
        $recibo_cinerarios = recibo_cinerario::with('familiar_difuntos_cremados', 'detalle_recibo_cinerario')->find($id);
        $pdf = pdf::loadView('recibo_cinerario.export', ['recibo_cinerarios' => $recibo_cinerarios]);
        return $pdf->stream('boleta.pdf');
}
}
