<?php

use App\Http\Controllers\AlquierController;
use App\Http\Controllers\ArrendatarioController;
use App\Http\Controllers\CinerarioController;
use App\Http\Controllers\difuntoController;
use App\Http\Controllers\InmuebleController;
use App\Http\Controllers\lapidaController;
use App\Http\Controllers\NichosController;
use App\Http\Controllers\PabellonController;
use App\Http\Controllers\recibo_cinerariosController;
use App\Http\Controllers\ReciboController;
use App\Http\Controllers\ReporteController;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;

Route::get('/', function () {
    return redirect('/login'); // Redirige al usuario al formulario de inicio de sesión de Breeze
});

Auth::routes();

Route::get('/home', [App\Http\Controllers\HomeController::class, 'index'])->name('home');

Route::controller(InmuebleController::class)->prefix('inmueble')->middleware('auth')->group(function () {
    Route::get('', 'index')->name('inmueble');
    Route::get('create', 'create')->name('inmueble.create');
    Route::post('store', 'store')->name('inmueble.store');
    Route::post('search', 'search')->name('inmueble.search');
    Route::get('edit/{id}', 'edit')->name('inmueble.edit');
    Route::put('edit/{id}', 'update')->name('inmueble.update');
    Route::delete('destroy/{id}', 'destroy')->name('inmueble.destroy');

});

Route::controller(ArrendatarioController::class)->prefix('arrendatario')->middleware('auth')->group(function () {
    Route::get('', 'index')->name('arrendatario');
    Route::get('create', 'create')->name('arrendatario.create');
    Route::post('store', 'store')->name('arrendatario.store');
    Route::post('search', 'search')->name('arrendatario.search');
    Route::get('edit/{id}', 'edit')->name('arrendatario.edit');
    Route::put('edit/{id}', 'update')->name('arrendatario.update');
    Route::delete('destroy/{id}', 'destroy')->name('arrendatario.destroy');
    Route::get('/arrendatario/search', [ArrendatarioController::class, 'search'])->name('arrendatario.search');
});

Route::controller(AlquierController::class)->prefix('alquiler')->middleware('auth')->group(function () {
    Route::get('', 'index')->name('alquiler');
    Route::get('create', 'create')->name('alquiler.create');
    Route::post('store', 'store')->name('alquiler.store');
    Route::post('search', 'search')->name('alquiler.search');
    Route::get('edit/{id}', 'edit')->name('alquiler.edit');
    Route::put('edit/{id}', 'update')->name('alquiler.update');
    Route::delete('destroy/{id}', 'destroy')->name('alquiler.destroy');
    Route::get('{alquiler}/export', 'export')->name('alquiler.export');
    Route::get('{alquiler}', 'show')->name('alquiler.show');
    Route::get('/alquiler/search', [AlquierController::class, 'search'])->name('alquiler.search');

});

Route::controller(ReporteController::class)->prefix('reporte')->middleware('auth')->group(function () {
    Route::get('', 'index')->name('reporte');
    Route::get('{arrendatarioId}/pagos', 'mostrarPagos')->name('reporte.pagos');
});

Route::controller(PabellonController::class)->prefix('pabellon')->middleware('auth')->group(function () {
    Route::get('', 'index')->name('pabellon');
    Route::get('create', 'create')->name('pabellon.create');
    Route::post('store', 'store')->name('pabellon.store');
    Route::post('search', 'search')->name('pabellon.search');
    Route::get('edit/{id}', 'edit')->name('pabellon.edit');
    Route::put('edit/{id}', 'update')->name('pabellon.update');
    Route::delete('destroy/{id}', 'destroy')->name('pabellon.destroy');
    Route::get('/pabellon/{id}', [PabellonController::class, 'show'])->middleware('auth')->name('pabellon.show');


});

Route::controller(NichosController::class)->prefix('nichos')->middleware('auth')->group(function () {
    Route::get('', 'index')->name('nichos');
    Route::get('/nichos/create/{id_nicho}', [NichosController::class, 'create'])->name('nichos.create');
    Route::post('store', 'store')->name('nichos.store');
    Route::post('search', 'search')->name('nichos.search');
    Route::get('edit/{id}', 'edit')->name('nichos.edit');
    Route::put('edit/{id}', 'update')->name('nichos.update');
    Route::delete('destroy/{id}', 'destroy')->name('nichos.destroy');

});

Route::controller(difuntoController::class)->prefix('difunto')->middleware('auth')->group(function () {
    Route::get('', 'index')->name('difunto');
    Route::get('/difunto/create/{id_nicho}', [difuntoController::class, 'create'])->name('difunto.create');
    Route::post('store', 'store')->name('difunto.store');
    Route::post('search', 'search')->name('difunto.search');
    Route::get('edit/{id}', 'edit')->name('difunto.edit');
    Route::put('edit/{id}', 'update')->name('difunto.update');
    Route::delete('destroy/{id}', 'destroy')->name('difunto.destroy');
    Route::get('{difunto}', 'show')->name('difunto.show');

});
Route::controller(ReciboController::class)->prefix('recibo')->middleware('auth')->group(function () {
    Route::get('', 'index')->name('recibo');
    Route::get('/recibo/create/{id_nicho}', [ReciboController::class, 'create'])->name('recibo.create');
    Route::post('store', [ReciboController::class, 'store'])->name('recibo.store'); // Corrected 'store' route
    Route::post('search', 'search')->name('recibo.search');
    Route::get('edit/{id}', 'edit')->name('recibo.edit');
    Route::put('edit/{id}', 'update')->name('recibo.update');
    Route::delete('destroy/{id}', 'destroy')->name('recibo.destroy');
    Route::get('{recibo}/export', 'export')->name('recibo.export');
    Route::get('{recibo}', 'show')->name('recibo.show');
Route::get('/buscar-dni/{dni}', [ReciboController::class, 'buscarDni'])->name('buscar-dni');
Route::get('/recibo/search', [ReciboController::class, 'search'])->name('recibo.search');



});

Route::controller(lapidaController::class)->prefix('lapida')->middleware('auth')->group(function () {
    Route::get('', 'index')->name('lapida');
    Route::get('create', 'create')->name('lapida.create');
    Route::post('store', 'store')->name('lapida.store');
    Route::post('search', 'search')->name('lapida.search');
    Route::get('edit/{id}', 'edit')->name('lapida.edit');
    Route::put('edit/{id}', 'update')->name('lapida.update');
    Route::delete('destroy/{id}', 'destroy')->name('lapida.destroy');
    Route::get('{lapida}', 'show')->name('lapida.show');
    Route::get('{lapida}/export', 'export')->name('lapida.export');
    Route::get('/lapida/search', [lapidaController::class, 'search'])->name('lapida.search');


});

Route::controller(CinerarioController::class)->prefix('cinerarios')->middleware('auth')->group(function () {
    Route::get('', 'index')->name('cinerarios');
    Route::get('/cinerarios/create/{id_cinerario}', [CinerarioController::class, 'create'])->name('cinerarios.create');
    Route::post('store', 'store')->name('cinerarios.store');
    Route::post('search', 'search')->name('cinerarios.search');
    Route::get('edit/{id}', 'edit')->name('cinerarios.edit');
    Route::put('edit/{id}', 'update')->name('cinerarios.update');
    Route::delete('destroy/{id}', 'destroy')->name('cinerarios.destroy');
});

Route::controller(recibo_cinerariosController::class)->prefix('recibo_cinerario')->middleware('auth')->group(function () {
    Route::get('', 'index')->name('recibo_cinerario');
    Route::get('/recibo_cinerario/create/{id_cinerario}', [recibo_cinerariosController::class, 'create'])->name('recibo_cinerario.create');
    Route::post('store', [recibo_cinerariosController::class, 'store'])->name('recibo_cinerario.store'); // Corrected 'store' route
    Route::post('search', 'search')->name('recibo_cinerario.search');
    Route::get('edit/{id}', 'edit')->name('recibo_cinerario.edit');
    Route::put('edit/{id}', 'update')->name('recibo_cinerario.update');
    Route::delete('destroy/{id}', 'destroy')->name('recibo_cinerario.destroy');
    Route::get('{recibo}/export', 'export')->name('recibo_cinerario.export');
    Route::get('{recibo}', 'show')->name('recibo_cinerario.show');
Route::get('/buscar-dni/{dni}', [recibo_cinerariosController::class, 'buscarDni'])->name('buscar-dni');





});